@@ -1,6 +1,6 @@
 import xcffib
 import struct
-import six
+import io
 MAJOR_VERSION = 3
 MINOR_VERSION = 1
 key = xcffib.ExtensionKey("SYNC")
@@ -35,7 +35,7 @@ class INT64(xcffib.Struct):
         self.hi, self.lo = unpacker.unpack("iI")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=iI", self.hi, self.lo))
         return buf.getvalue()
     fixed_size = 8
@@ -58,7 +58,7 @@ class SYSTEMCOUNTER(xcffib.Struct):
         self.name = xcffib.List(unpacker, "c", self.name_len)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IH", self.counter, self.name_len))
         buf.write(self.resolution.pack() if hasattr(self.resolution, "pack") else INT64.synthetic(*self.resolution).pack())
         buf.write(xcffib.pack_list(self.name, "c"))
@@ -82,7 +82,7 @@ class TRIGGER(xcffib.Struct):
         self.test_type, = unpacker.unpack("I")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=III", self.counter, self.wait_type, self.test_type))
         buf.write(self.wait_value.pack() if hasattr(self.wait_value, "pack") else INT64.synthetic(*self.wait_value).pack())
         return buf.getvalue()
@@ -105,7 +105,7 @@ class WAITCONDITION(xcffib.Struct):
         self.event_threshold = INT64(unpacker)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(self.trigger.pack() if hasattr(self.trigger, "pack") else TRIGGER.synthetic(*self.trigger).pack())
         buf.write(self.event_threshold.pack() if hasattr(self.event_threshold, "pack") else INT64.synthetic(*self.event_threshold).pack())
         return buf.getvalue()
@@ -124,7 +124,7 @@ class CounterError(xcffib.Error):
         self.bad_counter, self.minor_opcode, self.major_opcode = unpacker.unpack("xx2xIHB")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
         buf.write(struct.pack("=x2xIHB", self.bad_counter, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
@@ -139,7 +139,7 @@ class AlarmError(xcffib.Error):
         self.bad_alarm, self.minor_opcode, self.major_opcode = unpacker.unpack("xx2xIHB")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 1))
         buf.write(struct.pack("=x2xIHB", self.bad_alarm, self.minor_opcode, self.major_opcode))
         return buf.getvalue()
@@ -224,7 +224,7 @@ class CounterNotifyEvent(xcffib.Event):
         self.timestamp, self.count, self.destroyed = unpacker.unpack("IHBx")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
         buf.write(struct.pack("=B2xIIHBx", self.kind, self.counter, self.timestamp, self.count, self.destroyed))
         buf.write(self.wait_value.pack() if hasattr(self.wait_value, "pack") else INT64.synthetic(*self.wait_value).pack())
@@ -258,7 +258,7 @@ class AlarmNotifyEvent(xcffib.Event):
         self.timestamp, self.state = unpacker.unpack("IB3x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 1))
         buf.write(struct.pack("=B2xIIB3x", self.kind, self.alarm, self.timestamp, self.state))
         buf.write(self.counter_value.pack() if hasattr(self.counter_value, "pack") else INT64.synthetic(*self.counter_value).pack())
@@ -280,43 +280,43 @@ class AlarmNotifyEvent(xcffib.Event):
 _events[1] = AlarmNotifyEvent
 class syncExtension(xcffib.Extension):
     def Initialize(self, desired_major_version, desired_minor_version, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xBB", desired_major_version, desired_minor_version))
         return self.send_request(0, buf, InitializeCookie, is_checked=is_checked)
     def ListSystemCounters(self, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(1, buf, ListSystemCountersCookie, is_checked=is_checked)
     def CreateCounter(self, id, initial_value, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", id))
         buf.write(initial_value.pack() if hasattr(initial_value, "pack") else INT64.synthetic(*initial_value).pack())
         return self.send_request(2, buf, is_checked=is_checked)
     def DestroyCounter(self, counter, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", counter))
         return self.send_request(6, buf, is_checked=is_checked)
     def QueryCounter(self, counter, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", counter))
         return self.send_request(5, buf, QueryCounterCookie, is_checked=is_checked)
     def Await(self, wait_list_len, wait_list, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         buf.write(xcffib.pack_list(wait_list, WAITCONDITION))
         return self.send_request(7, buf, is_checked=is_checked)
     def ChangeCounter(self, counter, amount, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", counter))
         buf.write(amount.pack() if hasattr(amount, "pack") else INT64.synthetic(*amount).pack())
         return self.send_request(4, buf, is_checked=is_checked)
     def SetCounter(self, counter, value, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", counter))
         buf.write(value.pack() if hasattr(value, "pack") else INT64.synthetic(*value).pack())
         return self.send_request(3, buf, is_checked=is_checked)
     def CreateAlarm(self, id, value_mask, value_list, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", id, value_mask))
         if value_mask & CA.Counter:
             counter = value_list.pop(0)
@@ -338,7 +338,7 @@ class syncExtension(xcffib.Extension):
             buf.write(struct.pack("=I", events))
         return self.send_request(8, buf, is_checked=is_checked)
     def ChangeAlarm(self, id, value_mask, value_list, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", id, value_mask))
         if value_mask & CA.Counter:
             counter = value_list.pop(0)
@@ -360,43 +360,43 @@ class syncExtension(xcffib.Extension):
             buf.write(struct.pack("=I", events))
         return self.send_request(9, buf, is_checked=is_checked)
     def DestroyAlarm(self, alarm, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", alarm))
         return self.send_request(11, buf, is_checked=is_checked)
     def QueryAlarm(self, alarm, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", alarm))
         return self.send_request(10, buf, QueryAlarmCookie, is_checked=is_checked)
     def SetPriority(self, id, priority, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIi", id, priority))
         return self.send_request(12, buf, is_checked=is_checked)
     def GetPriority(self, id, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", id))
         return self.send_request(13, buf, GetPriorityCookie, is_checked=is_checked)
     def CreateFence(self, drawable, fence, initially_triggered, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIB", drawable, fence, initially_triggered))
         return self.send_request(14, buf, is_checked=is_checked)
     def TriggerFence(self, fence, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", fence))
         return self.send_request(15, buf, is_checked=is_checked)
     def ResetFence(self, fence, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", fence))
         return self.send_request(16, buf, is_checked=is_checked)
     def DestroyFence(self, fence, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", fence))
         return self.send_request(17, buf, is_checked=is_checked)
     def QueryFence(self, fence, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", fence))
         return self.send_request(18, buf, QueryFenceCookie, is_checked=is_checked)
     def AwaitFence(self, fence_list_len, fence_list, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         buf.write(xcffib.pack_list(fence_list, "I"))
         return self.send_request(19, buf, is_checked=is_checked)
