@@ -1,6 +1,6 @@
 import xcffib
 import struct
-import six
+import io
 MAJOR_VERSION = 2
 MINOR_VERSION = 2
 key = xcffib.ExtensionKey("XVideo")
@@ -48,7 +48,7 @@ class Rational(xcffib.Struct):
         self.numerator, self.denominator = unpacker.unpack("ii")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=ii", self.numerator, self.denominator))
         return buf.getvalue()
     fixed_size = 8
@@ -67,7 +67,7 @@ class Format(xcffib.Struct):
         self.visual, self.depth = unpacker.unpack("IB3x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IB3x", self.visual, self.depth))
         return buf.getvalue()
     fixed_size = 8
@@ -89,7 +89,7 @@ class AdaptorInfo(xcffib.Struct):
         self.formats = xcffib.List(unpacker, Format, self.num_formats)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IHHHBx", self.base_id, self.name_size, self.num_ports, self.num_formats, self.type))
         buf.write(xcffib.pack_list(self.name, "c"))
         buf.write(xcffib.pack_list(self.formats, Format))
@@ -117,7 +117,7 @@ class EncodingInfo(xcffib.Struct):
         self.name = xcffib.List(unpacker, "c", self.name_size)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IHHH2x", self.encoding, self.name_size, self.width, self.height))
         buf.write(self.rate.pack() if hasattr(self.rate, "pack") else Rational.synthetic(*self.rate).pack())
         buf.write(xcffib.pack_list(self.name, "c"))
@@ -146,7 +146,7 @@ class Image(xcffib.Struct):
         self.data = xcffib.List(unpacker, "B", self.data_size)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IHHII", self.id, self.width, self.height, self.data_size, self.num_planes))
         buf.write(xcffib.pack_list(self.pitches, "I"))
         buf.write(xcffib.pack_list(self.offsets, "I"))
@@ -174,7 +174,7 @@ class AttributeInfo(xcffib.Struct):
         self.name = xcffib.List(unpacker, "c", self.size)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IiiI", self.flags, self.min, self.max, self.size))
         buf.write(xcffib.pack_list(self.name, "c"))
         return buf.getvalue()
@@ -201,7 +201,7 @@ class ImageFormatInfo(xcffib.Struct):
         self.vscanline_order, = unpacker.unpack("B11x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IBB2xBB2xB3xIIIB3xIIIIIIIIIB11x", self.id, self.type, self.byte_order, self.bpp, self.num_planes, self.depth, self.red_mask, self.green_mask, self.blue_mask, self.format, self.y_sample_bits, self.u_sample_bits, self.v_sample_bits, self.vhorz_y_period, self.vhorz_u_period, self.vhorz_v_period, self.vvert_y_period, self.vvert_u_period, self.vvert_v_period, self.vscanline_order))
         buf.write(xcffib.pack_list(self.guid, "B"))
         buf.write(xcffib.pack_list(self.vcomp_order, "B"))
@@ -242,7 +242,7 @@ class BadPortError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -257,7 +257,7 @@ class BadEncodingError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 1))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -272,7 +272,7 @@ class BadControlError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 2))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -287,7 +287,7 @@ class VideoNotifyEvent(xcffib.Event):
         self.reason, self.time, self.drawable, self.port = unpacker.unpack("xB2xIII")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
         buf.write(struct.pack("=B2xIII", self.reason, self.time, self.drawable, self.port))
         buf_len = len(buf.getvalue())
@@ -312,7 +312,7 @@ class PortNotifyEvent(xcffib.Event):
         self.time, self.port, self.attribute, self.value = unpacker.unpack("xx2xIIIi")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 1))
         buf.write(struct.pack("=x2xIIIi", self.time, self.port, self.attribute, self.value))
         buf_len = len(buf.getvalue())
@@ -427,84 +427,84 @@ class QueryImageAttributesCookie(xcffib.Cookie):
     reply_type = QueryImageAttributesReply
 class xvExtension(xcffib.Extension):
     def QueryExtension(self, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, QueryExtensionCookie, is_checked=is_checked)
     def QueryAdaptors(self, window, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", window))
         return self.send_request(1, buf, QueryAdaptorsCookie, is_checked=is_checked)
     def QueryEncodings(self, port, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", port))
         return self.send_request(2, buf, QueryEncodingsCookie, is_checked=is_checked)
     def GrabPort(self, port, time, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", port, time))
         return self.send_request(3, buf, GrabPortCookie, is_checked=is_checked)
     def UngrabPort(self, port, time, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", port, time))
         return self.send_request(4, buf, is_checked=is_checked)
     def PutVideo(self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIIhhHHhhHH", port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h))
         return self.send_request(5, buf, is_checked=is_checked)
     def PutStill(self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIIhhHHhhHH", port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h))
         return self.send_request(6, buf, is_checked=is_checked)
     def GetVideo(self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIIhhHHhhHH", port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h))
         return self.send_request(7, buf, is_checked=is_checked)
     def GetStill(self, port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIIhhHHhhHH", port, drawable, gc, vid_x, vid_y, vid_w, vid_h, drw_x, drw_y, drw_w, drw_h))
         return self.send_request(8, buf, is_checked=is_checked)
     def StopVideo(self, port, drawable, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", port, drawable))
         return self.send_request(9, buf, is_checked=is_checked)
     def SelectVideoNotify(self, drawable, onoff, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIB3x", drawable, onoff))
         return self.send_request(10, buf, is_checked=is_checked)
     def SelectPortNotify(self, port, onoff, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIB3x", port, onoff))
         return self.send_request(11, buf, is_checked=is_checked)
     def QueryBestSize(self, port, vid_w, vid_h, drw_w, drw_h, motion, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIHHHHB3x", port, vid_w, vid_h, drw_w, drw_h, motion))
         return self.send_request(12, buf, QueryBestSizeCookie, is_checked=is_checked)
     def SetPortAttribute(self, port, attribute, value, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIi", port, attribute, value))
         return self.send_request(13, buf, is_checked=is_checked)
     def GetPortAttribute(self, port, attribute, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", port, attribute))
         return self.send_request(14, buf, GetPortAttributeCookie, is_checked=is_checked)
     def QueryPortAttributes(self, port, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", port))
         return self.send_request(15, buf, QueryPortAttributesCookie, is_checked=is_checked)
     def ListImageFormats(self, port, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", port))
         return self.send_request(16, buf, ListImageFormatsCookie, is_checked=is_checked)
     def QueryImageAttributes(self, port, id, width, height, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIHH", port, id, width, height))
         return self.send_request(17, buf, QueryImageAttributesCookie, is_checked=is_checked)
     def PutImage(self, port, drawable, gc, id, src_x, src_y, src_w, src_h, drw_x, drw_y, drw_w, drw_h, width, height, data_len, data, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIIIhhHHhhHHHH", port, drawable, gc, id, src_x, src_y, src_w, src_h, drw_x, drw_y, drw_w, drw_h, width, height))
         buf.write(xcffib.pack_list(data, "B"))
         return self.send_request(18, buf, is_checked=is_checked)
     def ShmPutImage(self, port, drawable, gc, shmseg, id, offset, src_x, src_y, src_w, src_h, drw_x, drw_y, drw_w, drw_h, width, height, send_event, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIIIIIhhHHhhHHHHB3x", port, drawable, gc, shmseg, id, offset, src_x, src_y, src_w, src_h, drw_x, drw_y, drw_w, drw_h, width, height, send_event))
         return self.send_request(19, buf, is_checked=is_checked)
 xcffib._add_ext(key, xvExtension, _events, _errors)
